@@ -8,7 +8,7 @@ Z <- dat$Z
 X <- dat$X
 set.seed(111)
 Sys.setenv(R_FUTURE_SUPPORTSMULTICORE_UNSTABLE="quiet")
-future::plan(strategy = future::multiprocess)
+future::plan(strategy = future::sequential)
 fitkm.list <- kmbayes_parallel(nchains=2, y = y, Z = Z, X = X, iter = 10,
                                verbose = FALSE, varsel = TRUE, family="binomial")
 sinkit = kmbayes_diag(fitkm.list)
